@@ -14,12 +14,12 @@
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   Lesser General Public License for more details.
    
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02111 USA.
+   Boston, MA 02110 USA.
 
    AutogsdocSource: NSKeyedArchiver.m
    AutogsdocSource: NSKeyedUnarchiver.m
@@ -52,6 +52,7 @@ extern "C" {
  */
 @interface NSKeyedArchiver : NSCoder
 {
+#if	GS_EXPOSE(NSKeyedArchiver)
 @private
   NSMutableData	*_data;		/* Data to write into.		*/
   id		_delegate;	/* Delegate controls operation.	*/
@@ -69,6 +70,16 @@ extern "C" {
   NSMutableDictionary	*_enc;	/* Object being encoded.	*/
   NSMutableArray	*_obj;	/* Array of objects.		*/
   NSPropertyListFormat	_format;
+#endif
+#if     GS_NONFRAGILE
+#else
+  /* Pointer to private additional data used to avoid breaking ABI
+   * when we don't have the non-fragile ABI available.
+   * Use this mechanism rather than changing the instance variable
+   * layout (see Source/GSInternal.h for details).
+   */
+  @private id _internal GS_UNUSED_IVAR;
+#endif
 }
 
 /**
@@ -121,7 +132,7 @@ extern "C" {
  * and associates the encoded value with aKey.
  */
 - (void) encodeBytes: (const uint8_t*)aPointer
-	      length: (unsigned)length
+	      length: (NSUInteger)length
 	      forKey: (NSString*)aKey;
 
 /**
@@ -216,6 +227,7 @@ extern "C" {
  */
 @interface NSKeyedUnarchiver : NSCoder
 {
+#if	GS_EXPOSE(NSKeyedUnarchiver)
 @private
   NSDictionary	*_archive;
   id		_delegate;	/* Delegate controls operation.	*/
@@ -230,9 +242,19 @@ extern "C" {
 #endif
   GSIArray		_objMap; /* Decoded objects.		*/
 #ifndef	_IN_NSKEYEDUNARCHIVER_M
-#undef	GSUnarchiverArray
+#undef	GSIArray
 #endif
   NSZone	*_zone;		/* Zone for allocating objs.	*/
+#endif
+#if     GS_NONFRAGILE
+#else
+  /* Pointer to private additional data used to avoid breaking ABI
+   * when we don't have the non-fragile ABI available.
+   * Use this mechanism rather than changing the instance variable
+   * layout (see Source/GSInternal.h for details).
+   */
+  @private id _internal GS_UNUSED_IVAR;
+#endif
 }
 
 /**
@@ -298,7 +320,7 @@ extern "C" {
  * -encodeBytes:length:forKey:
  */
 - (const uint8_t*) decodeBytesForKey: (NSString*)aKey
-		      returnedLength: (unsigned*)length;
+		      returnedLength: (NSUInteger*)length;
 
 /**
  * Returns a double value associated with aKey.  This value must previously
@@ -385,6 +407,7 @@ extern "C" {
 @interface	NSKeyedUnarchiver (Internal)
 - (id) _decodeArrayOfObjectsForKey: (NSString*)aKey;
 - (id) _decodePropertyListForKey: (NSString*)aKey;
+- (BOOL) replaceObject: (id)oldObj withObject: (id)newObj;
 @end
 
 
